@@ -1,4 +1,4 @@
-/* $Id: xfce-desktopentry.c 914 2005-01-17 01:52:30Z kelnos $ */
+/* $Id: xfce-desktopentry.c 19922 2006-02-17 16:54:40Z kelnos $ */
 /*-
  * Copyright (C) 2004 Jasper Huijsmans <jasper@xfce.org>
  *
@@ -284,7 +284,7 @@ entry_parse (XfceDesktopEntry * desktop_entry)
     int locale_matched = 0;
     char **lines, **p;
     char *current_section = NULL;
-    gboolean result = FALSE;
+    gboolean in_d_e_section = FALSE, result = FALSE;
 
     g_return_val_if_fail (XFCE_IS_DESKTOP_ENTRY (desktop_entry), FALSE);
 
@@ -298,6 +298,17 @@ entry_parse (XfceDesktopEntry * desktop_entry)
 	int i;
 	char *section, *key, *value, *locale;
 	
+    /* some .desktop files have multiple sections.  we're only interested
+     * in the "[Desktop Entry]" section */
+    if (!in_d_e_section) {
+        if (!g_ascii_strncasecmp(*p, "[Desktop Entry]", 15))
+            in_d_e_section = TRUE;
+    } else if (**p == '[' && g_ascii_strncasecmp(*p, "[Desktop Entry]", 15))
+        in_d_e_section = FALSE;
+    
+    if (!in_d_e_section)
+        continue;
+    
 	if (!parse_desktop_entry_line (*p, &section, &key, &value, &locale))
 	    continue;
 
@@ -572,3 +583,41 @@ xfce_desktop_entry_get_int (XfceDesktopEntry * desktop_entry,
 
     return FALSE;
 }
+
+/**
+ * xfce_desktop_entry_has_translated_entry:
+ * @desktop_entry: an #XfceDesktopEntry.
+ * @key: the key to check.
+ * @Returns: %TRUE if there is a translated key, %FALSE otherwise.
+ *
+ * Checks to see if @desktop_entry has a value for @key translated into
+ * the current locale.
+ *
+ * Since: 4.3
+ **/
+gboolean
+xfce_desktop_entry_has_translated_entry (XfceDesktopEntry *desktop_entry,
+                                         const char *key)
+{
+    const entry_t *entry;
+    const char *current_locale;
+    
+    g_return_val_if_fail(XFCE_IS_DESKTOP_ENTRY(desktop_entry)
+                         && key && *key, FALSE);
+    
+    if(!(entry = xfce_desktop_entry_get_entry(desktop_entry, key)))
+        return FALSE;
+    
+    if(!entry->value || !strlen(entry->value))
+        return FALSE;
+    
+    current_locale = setlocale(LC_MESSAGES, NULL);
+    
+    if(!entry->translated_value && !xfce_locale_match(current_locale, "C")
+       && !xfce_locale_match(current_locale, "POSIX"))
+    {
+        return FALSE;
+    }
+    
+    return TRUE;
+}
