@@ -1,28 +1,22 @@
-/* $Id: xfce-rc-simple.c 894 2004-11-18 23:27:57Z benny $ */
+/* $Id: xfce-rc-simple.c 20574 2006-03-26 09:59:34Z benny $ */
 /*-
- * Copyright (c) 2003-2004 Benedikt Meurer <benny@xfce.org>
+ * Copyright (c) 2003-2005 Benedikt Meurer <benny@xfce.org>
  * All rights reserved.
  *
- * Redistribution and use in source and binary forms, with or without
- * modification, are permitted provided that the following conditions
- * are met:
+ * This library is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU Library General Public
+ * License as published by the Free Software Foundation; either
+ * version 2 of the License, or (at your option) any later version.
  *
- * 1. Redistributions of source code must retain the above copyright
- *    notice, this list of conditions and the following disclaimer.
- * 2. Redistributions in binary form must reproduce the above copyright
- *    notice, this list of conditions and the following disclaimer in the
- *    documentation and/or other materials provided with the distribution.
+ * This library is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * Library General Public License for more details.
  *
- * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR
- * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
- * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
- * IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT,
- * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
- * NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
- * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
- * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
- * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
- * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
+ * You should have received a copy of the GNU Library General Public
+ * License along with this library; if not, write to the
+ * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
+ * Boston, MA 02111-1307, USA.
  */
 
 #ifdef HAVE_CONFIG_H
@@ -179,7 +173,28 @@ simple_add_entry (XfceRcSimple *simple,
 
   if (G_UNLIKELY (entry == NULL))
     {
-      g_return_val_if_fail (locale == NULL, NULL);
+      if (locale != NULL) {
+        /* this point is reached when there is a .desktop file that lists a language specific key for something that had no language-neutral key yet.
+           Example:
+             b.desktop
+             
+             [Desktop Entry]
+             Version=1.0
+             Encoding=UTF-8
+             Name=xyz
+             GenericName[de_AT]=Test
+             
+           here GenericName[de_AT] will end up here.
+           The previous way with g_return_val_if_fail would call an assertion failure and terminate the _whole application_(!!).
+           
+           Saner ways to react are either just ignoring GenericName[de_AT] altogether, or, alternatively, just set the normal GenericName
+           to Test too (i.e. imply GenericName=Test).
+           
+           For now, we are just ignoring the line altogether. But we aren't assert-failing anymore and the apps dont crash anymore.
+           */
+        return NULL;
+      }
+      /* why you annoying macro, will you stop borking libxfceutil? thanks. DO NOT DO THAT: g_return_val_if_fail (locale == NULL, NULL); */
 
       entry         = g_chunk_new (Entry, simple->entry_chunk);
       entry->key    = g_string_chunk_insert (simple->string_chunk, key);
@@ -354,19 +369,24 @@ simple_parse_line (gchar  *line,
 
       q = r + strlen (r);
 
-      while (q > r && (g_ascii_isspace (*(q-1)) || ((*(q-1)) == '\r')))
+      /* "\ " at the end of the string will not be removed */
+      while (q > r && ((g_ascii_isspace (*(q-1)) && *(q-2) != '\\') || ((*(q-1)) == '\r')))
         --q;
 
       *value = r;
       *q = '\0';
 
-      /* unescape \n, \t, \r and \\ */
+      /* unescape \ , \n, \t, \r and \\ */
       for (p = r; *r != '\0'; )
         {
           if (G_UNLIKELY (*r == '\\'))
             {
               switch (*(r+1))
                 {
+                case ' ':
+                  *p++ = ' ';
+                  break;
+
                 case 'n':
                   *p++ = '\n';
                   break;
@@ -406,11 +426,36 @@ simple_parse_line (gchar  *line,
 static gchar*
 simple_escape (gchar *buffer, gsize size, const gchar *string)
 {
-  gchar *p;
+  const gchar *s;
+  gchar       *p;
 
-  for (p = buffer; p - buffer < size - 2 && *string != '\0'; ++string)
+  /* escape all whitespace at the beginning of the string */
+  for (p = buffer; p - buffer < size - 2 && *string == ' '; ++string)
+    {
+      *p++ = '\\';
+      *p++ = ' ';
+    }
+
+  for (; p - buffer < size - 2 && *string != '\0'; ++string)
     switch (*string)
       {
+      case ' ':
+        /* check if any non whitespace characters follow */
+        for (s = string + 1; g_ascii_isspace (*s); ++s)
+          ;
+        if (*s == '\0')
+          {
+            /* need to escape the space */
+            *p++ = '\\';
+            *p++ = ' ';
+          }
+        else
+          {
+            /* still non-whitespace, no need to escape */
+            *p++ = ' ';
+          }
+        break;
+
       case '\n':
         *p++ = '\\';
         *p++ = 'n';
